package mining

import (
	"fmt"
	miningCfg "server/conf/mining"
	"server/game/mod/item"
)

type MiningMod struct {
	Id     int
	Map    map[int32]string
	Gem    []int
	Pass   int
	Mining int
}

func (m *MiningMod) InitData() {
	if m.Map == nil {
		m.Map = make(map[int32]string)
	}
}

func (m *MiningMod) Login(Id int) {
	if Id == 0 {
		return
	}
	if m.Id == Id {
		return
	}
	m.Id = Id
	m.Map = make(map[int32]string)
	m.Gem = make([]int, 0)
	m.Pass = 1
	m.Mining = 0
}

func (m *MiningMod) ZeroUpdate(Id int) {
	m.Login(Id)
}

func (m *MiningMod) GetMap() map[int32]string {
	return m.Map
}

func (m *MiningMod) GetGem() []int {
	return m.Gem
}

func (m *MiningMod) GetPass() int {
	return m.Pass
}

func (m *MiningMod) GetMining() int {
	return m.Mining
}

func (m *MiningMod) Take(Map map[int32]string, Gem int) ([]*item.Item, error) {
	m.Map = Map
	m.Mining++
	AreaNum := miningCfg.GetPassArea(m.Pass)
	if AreaNum == 0 {
		return nil, fmt.Errorf("pass is not exist")
	}
	if m.Mining > AreaNum {
		return nil, fmt.Errorf("mining is full")
	}
	if Gem > 0 {
		m.Gem = append(m.Gem, Gem)
		GemList := miningCfg.GetPassGem(m.Pass)
		if len(m.Gem) > len(GemList) {
			return nil, fmt.Errorf("gem is full")
		}
	} else {
		Items := miningCfg.GetRandItem()
		return Items, nil
	}

	return nil, nil
}

func (m *MiningMod) GetReward() ([]*item.Item, error) {
	GemList := miningCfg.GetPassGem(m.Pass)
	if len(m.Gem) < len(GemList) {
		return nil, fmt.Errorf("gem is not full")
	}
	Items := miningCfg.GetPassItem(m.Pass)
	m.Pass++
	m.Mining = 0
	m.Gem = make([]int, 0)
	return Items, nil
}
